@@ -1,9 +1,8 @@
-import json
 import requests
+import ujson as json
 from time import time as timestamp
 
-from .lib import api
-from .lib import headers
+from .lib import *
 from .lib.objects import *
 from .lib import CheckExceptions
 
@@ -16,22 +15,23 @@ class Acm:
         self.uid = headers.Headers().uid
         self.headers = headers.Headers().headers
         self.api = "https://service.narvii.com/api/v1"
+        self.session = requests.Session()
 
     def promote(self, userId: str, rank: str):
         rank = rank.lower()
         if rank not in ["agent", "leader", "curator"]: raise TypeError(rank)
         rank = rank.replace("agent", "transfer-agent")
-        req = requests.post(api(f"/x{self.comId}/s/user-profile/{userId}/{rank}"), headers=self.headers, proxies=self.proxies)
+        req = self.session.post(api(f"/x{self.comId}/s/user-profile/{userId}/{rank}"), headers=self.headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
     def accept_join_request(self, userId: str):
-        req = requests.post(api(f"/x{self.comId}/s/community/membership-request/{userId}/accept"), headers=self.headers, proxies=self.proxies)
+        req = self.session.post(api(f"/x{self.comId}/s/community/membership-request/{userId}/accept"), headers=self.headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
     def reject_join_request(self, userId: str):
-        req = requests.post(api(f"/x{self.comId}/s/community/membership-request/{userId}/reject"), headers=self.headers, proxies=self.proxies)
+        req = self.session.post(api(f"/x{self.comId}/s/community/membership-request/{userId}/reject"), headers=self.headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
@@ -41,13 +41,13 @@ class Acm:
             "value": {"enabled": enabled, "text": message},
             "timestamp": int(timestamp() * 1000)
         })
-        req = requests.post(api(f"/x{self.comId}/s/community/configuration"), data=data, headers=headers.Headers(data=data).headers, proxies=self.proxies)
+        req = self.session.post(api(f"/x{self.comId}/s/community/configuration"), data=data, headers=headers.Headers(data=data).headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
     def change_guidelines(self, content: str):
         data = json.dumps({"content": content, "timestamp": int(timestamp() * 1000)})
-        req = requests.post(api(f"/x{self.comId}/s/community/guideline"), headers=headers.Headers(data=data).headers, data=data, proxies=self.proxies)
+        req = self.session.post(api(f"/x{self.comId}/s/community/guideline"), headers=headers.Headers(data=data).headers, data=data, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
@@ -61,12 +61,12 @@ class Acm:
         if themePackUrl: data["themePackUrl"] = themePackUrl
 
         data = json.dumps(data)
-        req = requests.post(api(f"/x{self.comId}/s/community/settings"), data=data, headers=headers.Headers(data=data).headers, proxies=self.proxies)
+        req = self.session.post(api(f"/x{self.comId}/s/community/settings"), data=data, headers=headers.Headers(data=data).headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
     def get_community_stats(self):
-        req = requests.get(api(f"/x{self.comId}/s/community/stats"), headers=self.headers)
+        req = self.session.get(api(f"/x{self.comId}/s/community/stats"), headers=self.headers)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return CommunityStats(req.json()["communityStats"]).CommunityStats
 
@@ -77,28 +77,28 @@ class Acm:
         elif type == "curator": pass
         else: raise TypeError(type)
 
-        req = requests.get(api(f"/x{self.comId}/s/community/stats/moderation?type={type}&start={start}&size={size}"), headers=self.headers, proxies=self.proxies)
+        req = self.session.get(api(f"/x{self.comId}/s/community/stats/moderation?type={type}&start={start}&size={size}"), headers=self.headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
     def get_join_requests(self, start: int = 0, size: int = 25):
-        req = requests.get(api(f"/x{self.comId}/s/community/membership-request?status=pending&start={start}&size={size}"), headers=self.headers, proxies=self.proxies)
+        req = self.session.get(api(f"/x{self.comId}/s/community/membership-request?status=pending&start={start}&size={size}"), headers=self.headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return JoinRequest(req.json()).JoinRequest
 
     def get_all_members(self, type: str, start: int = 0, size: int = 25):
         type = type.lower()
-        req = requests.get(api(f"/x{self.comId}/s/user-profile?type={type}&start={start}&size={size}"), headers=self.headers, proxies=self.proxies)
+        req = self.session.get(api(f"/x{self.comId}/s/user-profile?type={type}&start={start}&size={size}"), headers=self.headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return UserProfileList(req.json()["userProfileList"]).UserProfileList
 
     def add_influencer(self, userId: str, monthlyFee: int = 50):
         data = json.dumps({"monthlyFee": monthlyFee, "timestamp": int(timestamp() * 1000)})
-        req = requests.post(api(f"/x{self.comId}/s/influencer/{userId}"), data=data, headers=headers.Headers(data=data).headers, proxies=self.proxies)
+        req = self.session.post(api(f"/x{self.comId}/s/influencer/{userId}"), data=data, headers=headers.Headers(data=data).headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
 
     def remove_influencer(self, userId: str):
-        req = requests.delete(api(f"/x{self.comId}/s/influencer/{userId}"), headers=self.headers, proxies=self.proxies)
+        req = self.session.delete(api(f"/x{self.comId}/s/influencer/{userId}"), headers=self.headers, proxies=self.proxies)
         if req.status_code != 200: return CheckExceptions(req.json())
         else: return Json(req.json())
